@@ -3,7 +3,7 @@
 from .client import ONVIFClient
 from .operator import ONVIFOperator, CacheMode
 from .utils import ONVIFWSDL, ONVIFOperationException
-from .utils.zeep import apply_patch
+from .utils.zeep import apply_patch, remove_patch, is_patched
 
 __all__ = [
     "ONVIFClient",
@@ -11,6 +11,7 @@ __all__ = [
     "CacheMode",
     "ONVIFWSDL",
     "ONVIFOperationException",
-]
-
-apply_patch()
\ No newline at end of file
+    "apply_patch",
+    "remove_patch", 
+    "is_patched",
+]
\ No newline at end of file
